ImageDenoiserClassic - Classic Image Denoiser
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. currentmodule:: aydin.it.classic

.. autoclass:: ImageDenoiserClassic
    :members:
    :inherited-members:
